Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2270)

Unified Diff: content/public/common/content_switches.cc

Issue 8771056: Add a command-line switch --enable-per-tile-painting. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Rebase on master. Created 9 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/public/common/content_switches.h ('k') | webkit/glue/webpreferences.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/public/common/content_switches.cc
diff --git a/content/public/common/content_switches.cc b/content/public/common/content_switches.cc
index 8b0463d343360e8211b1a224e5b2895b27179921..d9701ab946f6c27a013196f6c2c61c422cc10555 100644
--- a/content/public/common/content_switches.cc
+++ b/content/public/common/content_switches.cc
@@ -170,11 +170,11 @@ const char kDisableWebSockets[] = "disable-web-sockets";
// Enable gpu-accelerated 2d canvas.
const char kEnableAccelerated2dCanvas[] = "enable-accelerated-2d-canvas";
// Enable hardware accelerated page drawing.
// Please note that this flag is honored only if chromium is compiled with
alokp 2011/12/13 17:20:16 Would you mind removing this comment? It is not tr
// SKIA_GPU flag, which can be enabled by setting use_skia_gpu variable to 1
// in build/features_override.gypi.
-const char kEnableAcceleratedDrawing[] = "enable-accelerated-drawing";
+const char kEnableAcceleratedPainting[] = "enable-accelerated-painting";
// Enable gpu-accelerated SVG/W3C filters.
const char kEnableAcceleratedFilters[] = "enable-accelerated-filters";
@@ -559,4 +559,10 @@ const char kUseSystemSSL[] = "use-system-ssl";
const char kRendererCheckFalseTest[] = "renderer-check-false-test";
#endif
+// Enable per-tile page painting.
+// Please note that this flag is honored only if chromium is compiled with
+// SKIA_GPU flag, which can be enabled by setting use_skia_gpu variable to 1
+// in build/features_override.gypi.
+const char kEnablePerTilePainting[] = "enable-per-tile-painting";
+
} // namespace switches
« no previous file with comments | « content/public/common/content_switches.h ('k') | webkit/glue/webpreferences.h » ('j') | no next file with comments »
@@ -170,11 +170,11 @@ const char kDisableWebSockets[] = "disable-web-sockets";
// Enable gpu-accelerated 2d canvas.
const char kEnableAccelerated2dCanvas[] = "enable-accelerated-2d-canvas";
-// Enable hardware accelerated page drawing.
+// Enable hardware accelerated page painting.
// Please note that this flag is honored only if chromium is compiled with
alokp 2011/12/13 17:20:16 Would you mind removing this comment? It is not tr

Powered by Google App Engine
This is Rietveld 408576698